// vim: set tw=80 ts=2 sw=2 sts=2 :
import { Component, OnInit, OnChanges, Input, Output, EventEmitter } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';

import { Account } from './account';

@Component({
  selector: 'account-form',
  exportAs: 'accountForm',
  template: `
<form novalidate (keyup.enter)="submit()" [formGroup]="form">
  <md-list>
    <md-list-item>
      <md-form-field>
        <input mdInput formControlName="name" placeholder="Account name">

        <md-error *ngIf="name.errors?.required">The account name is required.</md-error>
      </md-form-field>
    </md-list-item>

    <md-list-item>
      <md-form-field>
        <span mdPrefix>-</span>
        <input mdInput formControlName="authorizedOverdraft"
          placeholder="Authorized overdraft">
        <span mdSuffix>.00€</span>

        <md-error *ngIf="authorizedOverdraft.errors?.required">
          The authorized overdraft is required.
        </md-error>

        <md-error *ngIf="authorizedOverdraft.errors?.min">
          The authorized overdraft must be less than or equal to 0.
        </md-error>
      </md-form-field>
    </md-list-item>
  </md-list>
</form>
  `
})
export class AccountFormComponent implements OnInit {
  public form: FormGroup;
  @Input() account: Account;
  @Output('submit') submitEventEmitter: EventEmitter<void> = new EventEmitter<void>();

  constructor(private formBuilder: FormBuilder) {}

  ngOnInit() {
    this.form = this.formBuilder.group({
      name: ['', Validators.required],
      authorizedOverdraft: ['', [Validators.required, Validators.min(0)]],
    });

    this.form.patchValue({
      name: this.account.name,
      authorizedOverdraft: -this.account.authorized_overdraft
    });
  }

  submit() {
    if(this.form.valid) {
      this.submitEventEmitter.emit();
    }
  }

  get name() {
    return this.form.get('name');
  }

  get authorizedOverdraft() {
    return this.form.get('authorizedOverdraft');
  }
}
