// vim: set tw=80 ts=2 sw=2 sts=2:

import { Injectable } from '@angular/core';
import { DataSource } from '@angular/cdk/collections';
import { Observable } from 'rxjs';
import { BehaviorSubject } from 'rxjs';

import { Logger } from '@nsalaun/ng-logger';

import { Schedule } from './schedule';
import { ScheduleService } from './schedule.service';

@Injectable()
export class ScheduleDataSource extends DataSource<Schedule> {
  private subject: BehaviorSubject<number> = new BehaviorSubject<number>(null);

  constructor(
    private scheduleService: ScheduleService,
    private logger: Logger,
  ) {
    super();
  }

  load(accountId: number): void {
    this.logger.log("In load", accountId);
    this.subject.next(accountId);
  }

  connect(): Observable<Schedule[]> {
    return this.subject.asObservable().concatMap((accountId: number) => {
      this.logger.log("In connect", accountId);

      if(accountId) {
        return this.scheduleService.query(accountId);
      }
    });
  }

  disconnect() {}
}
